#
# spec file for package mate-polkit
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soname   libpolkit-gtk-mate-1
%define sover    0
%define typelib  typelib-1_0-PolkitGtkMate-1.0
%define _name    polkit-mate-1
%define _version 1.28

Name:           mate-polkit
Version:        1.28.1
Release:        bp160.1.9
Summary:        MATE authentification agent for polkit
License:        LGPL-2.0-or-later
Group:          Productivity/Security
URL:            https://mate-desktop.org/
Source:         https://pub.mate-desktop.org/releases/%{_version}/%{name}-%{version}.tar.xz
BuildRequires:  mate-common >= %{_version}
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(accountsservice)
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(polkit-agent-1)
Recommends:     %{name}-lang
# typelib-1_0-PolkitGtkMate-1.0 was last used in openSUSE Leap 42.3.
Obsoletes:      typelib-1_0-PolkitGtkMate-1.0 < %{version}
# libpolkit-gtk-mate-1-0 was last used in openSUSE Leap 42.3.
Obsoletes:      libpolkit-gtk-mate-1-0 < %{version}
# mate-polkit-devel was last used in openSUSE Leap 42.3.
Obsoletes:      %{name}-devel < %{version}
%if 0%{?is_opensuse}
%ifarch s390x ppc64 ppc64le
BuildRequires:  pkgconfig(appindicator3-0.1)
%else
BuildRequires:  pkgconfig(ayatana-appindicator3-0.1)
%endif
%endif

%description
mate-polkit provides a D-Bus session bus service that is used to bring
up authentication dialogues used for obtaining privileges.

%lang_package

%prep
%setup -q

%build
%meson
%meson_build

%install
%meson_install

%find_lang %{name} %{?no_lang_C}
%suse_update_desktop_file %{buildroot}%{_sysconfdir}/xdg/autostart/polkit-mate-authentication-agent-1.desktop

%files
%license COPYING
%doc AUTHORS NEWS README
%config %{_sysconfdir}/xdg/autostart/polkit-mate-authentication-agent-1.desktop
%{_libexecdir}/polkit-mate-authentication-agent-1

%files lang -f %{name}.lang

%changelog
* Wed Mar 27 2024 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.28.0
  * Translations update
  * Fix meson build libexecdir to the correct path
  * drop categories from desktop file
  * Distribute Meson build system
* Sun Dec  4 2022 Dirk Müller <dmueller@suse.com>
- update to 1.26.1:
  * Fix segfault from gdk_x11_get_server_time if not on X11
* Fri Aug 13 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.26.0
  * Update translations
  * Update copyright to 2021
* Wed Feb 26 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.24.0:
  * build: Show warning flags on configure summary.
  * build: Warning flags are already defined.
  * autoconf: AC_PROG_CC was called before AX_CHECK_ENABLE_DEBUG.
  * Migrate from intltool to gettext.
  * Update translations.
- Drop support for old openSUSE versions.
* Wed Jul 17 2019 Jonathan Brielmaier <jbrielmaier@suse.de>
- Update to version 1.23.0:
  * Translations update
  * Migrate from GSimpleAsyncResult to GTask
  * drop deprecated gtk_dialog_get_action_area
  * Avoid deprecated g_type_class_add_private
  * polkitmateauthenticationdialog: avoid GtkStock
  * Change url project's website
- remove patch:
  * mate-polkit-gtk-3.20.patch: we don't support gtk3.20 anymore
- build require gtk >= 3.22 and glib >= 2.50
* Tue Mar  5 2019 sor.alexei@meowr.ru
- Update to version 1.22.0:
  * Update translations.
* Sat Dec 22 2018 sor.alexei@meowr.ru
- Update to version 1.20.2:
  * Disable deprecation warnings for distcheck.
  * Update translations.
* Sat Jun 16 2018 sor.alexei@meowr.ru
- Update to version 1.20.1:
  * Update translations.
* Fri Mar  9 2018 sor.alexei@meowr.ru
- Update to version 1.20.0:
  * Require GTK+ 3.22 and GLib 2.50.
  * status-icon: Don't use stock icons.
  * polkitmateauthenticationdialog: Avoid deprecated GtkAlignment.
  * polkitmateauthenticationdialog: Replace a GtkStock deprecation.
  * Drop the polkitgtkmate library.
  * Update translations.
- Add mate-polkit-gtk-3.20.patch: Restore GLib 2.48 and GTK+ 3.20
  support.
- Drop the library, devel and typelib packages.
- Remove baselibs.conf.
* Sat Nov 18 2017 sor.alexei@meowr.ru
- Update to version 1.18.2:
  * Fix reshow/hide icon with statusnotifier.
  * Update translations.
* Tue May  9 2017 sor.alexei@meowr.ru
- Update to version 1.18.1:
  * Fix broken status icon if using GtkStatusIcon.
  * Update translations.
* Tue Mar 14 2017 sor.alexei@meowr.ru
- Update to version 1.18.0:
  * NEWS: use consistent, project wide, markdown-like formatting to
    make generating release announcements easier.
  * Fix some GTK+ deprecations.
  * Update translations.
* Tue Sep 20 2016 sor.alexei@meowr.ru
- Update to version 1.16.0:
  * Move to GTK+3 (require GTK+ >= 3.14), drop GTK+2 code and
  - -with-gtk build option
  * Update translations.
* Sat Apr  9 2016 sor.alexei@meowr.ru
- Update to version 1.14.0:
  * Update translations.
  * Add Changelog generation.
* Mon Jan 25 2016 sor.alexei@meowr.ru
- Update to version 1.13.0:
  * Gtk3: Fix several deprecations.
* Sun Jan  3 2016 sor.alexei@meowr.ru
- Switch to Gtk3.
* Thu Nov  5 2015 sor.alexei@meowr.ru
- Update to 1.12.0.
- Add baselibs.conf.
* Wed Oct 14 2015 sor.alexei@meowr.ru
- Update to 1.11.0:
  * GTK+3: add support for application indicators as well.
  * Some fixes and cleanups.
* Fri Sep 18 2015 sor.alexei@meowr.ru
- Update to 1.10.2:
  * Return error when authentication dialog is dismissed.
  * Optionally use accountsservice to retrieve face.
  * Add support for autorestart.
  * Select the current user to authenticate by default.
  * Add support for application indicators.
  * Gtk3: Auth dialog: make the label wrap at 50 chars.
* Wed Sep  2 2015 sor.alexei@meowr.ru
- Update to 1.10.1:
  * Fix losing focus when displaying password prompt dialog.
  * Drop some deprecated GTK+ code and obsolete build macro.
  * Update translations.
* Wed Apr 15 2015 p.drouand@gmail.com
- Update to version 1.10.0
  * No changes since version 1.9.90
* Mon Mar 23 2015 p.drouand@gmail.com
- Update to version 1.9.90 (unstable)
  * Translations updates
* Sun Oct 26 2014 p.drouand@gmail.com
- Update to version 1.9.0 (unstable)
  + Fix documentation license
    Closes #15 (https://github.com/mate-desktop/mate-polkit/issues/15)
- Minimal required version of mate-common is 1.9.0
* Wed Mar  5 2014 p.drouand@gmail.com
- Update to version 1.8.0
  + no changes since version 1.7.90
* Sat Feb 15 2014 p.drouand@gmail.com
- Update to version 1.7.90 (unstable)
  + major GTK3 improvements
* Mon Feb 10 2014 p.drouand@gmail.com
- Update to version 1.7.2 (unstable)
  + fix gtk-doc generation
  + update translations
- Changes from version 1.7.1
  + fix g_type_init deprecation
  + fix Makefile
  + fixes for make dist
  + use GTK_API_VERSION for gir-scanner
- Changes from version 1.7.0 (unstable)
  + use GtkBox in GTK3 instead of GtkHBox
  + allow deprecations to fix build with GTK3
  + get makefile compatible with automake-1.13
  + fix redundant entries name and comment in desktop file
  + initial GTK3 support
* Wed Jan  1 2014 p.drouand@gmail.com
- Update to version 1.6.1
  + Resurrect lost gtk doc xml file
  + Update POTFILES.skip
  + Use AM_CPPFLAGS instead of INCLUDES
  + Create xz tarballs
  + Add ChangeLog gen dist-hook
  + small autofoo fixes
  + Fixes for make dist
  + Add DISTCHECK_CONFIGURE_FLAGS for gtk doc and small autofoo fix
  + fix redundant entries name and comment in desktop file
* Wed Dec 18 2013 cfarrell@suse.com
- license update: LGPL-2.0+
  See COPYING
* Wed Dec 18 2013 p.drouand@gmail.com
- mate-polkit is licensed under GPLv2 and not GPLv3; change it
  in spec
* Fri Sep 20 2013 p.drouand@gmail.com
- Correct library subpackage group to System/Libraries
* Sat Apr  6 2013 p.drouand@gmail.com
- Split out the Typelib; fix shlib-fixed-dependency warning
* Wed Apr  3 2013 johann.luce@wanadoo.fr
- Update to version 1.6.0
  + update translations
  + fix deprecation, compile error & warnings
  + fix incorrect FSF addresses
* Wed Oct 10 2012 nmo.marques@gmail.com
- Update to version 1.5.0
  + no changelog available
* Sat Sep  8 2012 nmo.marques@gmail.com
- copypac to X11:MATE
  + minor cosmetic fixes
- update to version 1.4.0
  + fix %%find_lang macro; upstream changed language file names
* Sat Jun 16 2012 nmo.marques@gmail.com
- update to version 1.2.0
* Sun Jan 22 2012 nmarques@opensuse.org
- initial package from version 1.1.1
